@@ -570,7 +570,7 @@ class EssbasicClient(AbstractClient):
 
 
     def CreateSealByImage(self, request):
-        """渠道通过图片为子客代创建印章，图片最大5m；此接口不可直接使用，请联系运营/客服咨询相关流程
+        """渠道通过图片为子客代创建印章，图片最大5MB
 
         :param request: Request instance for CreateSealByImage.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateSealByImageRequest`
